pitchtools.PitchObjectSet
=========================

.. abjad-lineage:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet

.. autoclass:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rand__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ror__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rsub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rxor__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__xor__
   :noindex:
